@@ -5,6 +5,14 @@ import toml
 
 from .commands import to_csv, to_xml, to_xlsx, to_json, config
 from .commons.endpoints import default_endpoints
+from . import __version__
+
+
+def print_version(ctx, param, value):
+    if not value or ctx.resilient_parsing:
+        return
+    click.echo(f"Version {__version__}")
+    ctx.exit()
 
 
 @click.group()
@@ -15,6 +23,15 @@ from .commons.endpoints import default_endpoints
     default="~/.hycli/config.toml",
     show_default=True,
 )
+@click.option(
+    "-v",
+    "--version",
+    is_flag=True,
+    callback=print_version,
+    expose_value=False,
+    is_eager=True,
+    help="Print out hycli version",
+)
 @click.option(
     "-e",
     "--endpoint-env",
