@@ -22,7 +22,7 @@ def run_requests(workers: int, path: str, services) -> dict:
                 read_pdf(file_path),
                 services.extractor_endpoint,
                 file_extension,
-                services.token,
+                services.get_token,
                 services.headers,
             ): file_path
             for file_path, file_extension in files.items()
@@ -239,9 +239,15 @@ def structure_sheet(records):
         }
 
         # Reorder column order
-        records[idx] = {
-            **dict(itertools.islice(record.items(), 2)),
-            **dict(sorted(itertools.islice(record.items(), 2, None))),
-        }
+        if "error_message" in record or "row_number" in record:
+            records[idx] = {
+                **dict(itertools.islice(record.items(), 2)),
+                **dict(sorted(itertools.islice(record.items(), 2, None))),
+            }
+        else:
+            records[idx] = {
+                **dict(itertools.islice(record.items(), 1)),
+                **dict(sorted(itertools.islice(record.items(), 1, None))),
+            }
 
     return records
