@@ -8,7 +8,7 @@ from ..services.requests import extract_invoice
 from .commons import read_pdf, get_filenames
 
 
-def convert_to_json(path, extractor_endpoint, token, workers):
+def convert_to_json(path, extractor_endpoint, token, workers, headers):
     # Todo: add single invoice path besides dir
     files = get_filenames(path)
 
@@ -20,6 +20,7 @@ def convert_to_json(path, extractor_endpoint, token, workers):
                 extractor_endpoint,
                 file_extension,
                 token,
+                headers,
             ): file_path
             for file_path, file_extension in files.items()
         }
