@@ -29,6 +29,7 @@ class Services(object):
         self.validation_endpoint = endpoints.get("validation")
 
         self.token = None
+        self.token_counter = 0
         self.refresh_token()
 
     def are_up(self, endpoints):
@@ -55,6 +56,12 @@ class Services(object):
                     url_spinner.fail(f"{svc} endpoint returns {req.status_code}\n")
                     endpoints[name] = None
 
+    def get_token(self, refresh_on_every=50):
+        if self.token_counter % refresh_on_every == 0:
+            self.refresh_token()
+        self.token_counter += 1
+        return self.token
+
     def refresh_token(self):
         if self.env != "localhost":
             self.token = request_token(
